==> Flask-Collect-0.2.0.tar.gz: Flask-Collect-0.2.0/setup.py <==
#!/usr/bin/env python

"""
Flask-Collect
-------------

Setup module.

"""
from os import path
from sys import version_info

from setuptools import setup, find_packages

from flask_collect import __version__, __license__


def read(fname):
    try:
        return open(path.join(path.dirname(__file__), fname)).read()
    except IOError:
        return ''


install_requires = [
    l for l in read('requirements.txt').split('\n')
    if l and not l.startswith('#')]

if version_info < (2, 7):
    install_requires.append('importlib')


META_DATA = dict(
    name='Flask-Collect',
    version=__version__,
    license=__license__,
    description=read('DESCRIPTION'),
    long_description=read('README.rst'),
    platforms=('Any'),
    keywords = "flask static deploy".split(),

    author='Kirill Klenov',
    author_email='horneds@gmail.com',
    url=' http://github.com/klen/Flask-Collect',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Natural Language :: Russian',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ],

    packages=find_packages(),
    include_package_data=True,
    install_requires = install_requires,
    test_suite = 'tests',
)


if __name__ == "__main__":
    setup(**META_DATA)

==> Flask-Collect-0.2.3.tar.gz: Flask-Collect-0.2.3/setup.py <==
#!/usr/bin/env python

"""
Flask-Collect
-------------

Setup module.

"""
import re

from os import path
from sys import version_info

from setuptools import setup, find_packages


def _read(fname):
    try:
        return open(path.join(path.dirname(__file__), fname)).read()
    except IOError:
        return ''

_meta = _read('flask_collect/__init__.py')
_license = re.search(r'^__license__\s*=\s*"(.*)"', _meta, re.M).group(1)
_version = re.search(r'^__version__\s*=\s*"(.*)"', _meta, re.M).group(1)

install_requires = [
    l for l in _read('requirements.txt').split('\n')
    if l and not l.startswith('#')]

if version_info < (2, 7):
    install_requires.append('importlib')


META_DATA = dict(
    name='Flask-Collect',
    version=_version,
    license=_license,
    description=_read('DESCRIPTION'),
    long_description=_read('README.rst'),
    platforms=('Any'),
    keywords="flask static deploy".split(),

    author='Kirill Klenov',
    author_email='horneds@gmail.com',
    url=' http://github.com/klen/Flask-Collect',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Natural Language :: Russian',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ],

    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    test_suite='tests',
)


if __name__ == "__main__":
    setup(**META_DATA)
